#
# Use a real instrumentation key to test logs against a real
# instance of Application Insights - verification is done manually, sorry.
#
instrumentation_key = 'e92c88dc-fd0b-4b6f-a482-f35821b1dd7c'
